@@ -52,8 +52,10 @@ static GList *valid_devices = NULL;
 static GFloppyFormattingMode get_selected_formatting_mode ();
 static void type_option_changed_cb     (GtkOptionMenu   *option_menu,
 					gpointer         data);
+/*
 static void set_widget_sensitive_from  (GtkToggleButton *button,
 					gpointer         data);
+*/
 
 static void
 devices_option_activated (GtkWidget *menu_item, gchar *device)
@@ -128,7 +130,7 @@ init_commands (void)
 
 		error_dialog = gtk_message_dialog_new (NULL, 0,
 						       GTK_MESSAGE_ERROR,
-						       GTK_BUTTONS_CLOSE,
+						       GTK_BUTTONS_OK,
 						       _("Neither the mke2fs nor the mkdosfs/mformat applications are installed. You can't format a floppy without one of them."));
 
 		gtk_dialog_run (GTK_DIALOG (error_dialog));
@@ -143,6 +145,7 @@ init_devices (void)
 {
 	GtkWidget *device_option;
 	GtkWidget *device_entry;
+	GtkWidget *device_label;
 	gchar *msg = NULL;
 	gint ok_devices_present = 0;
 
@@ -170,7 +173,7 @@ init_devices (void)
 			gtk_widget_set_sensitive (toplevel, FALSE);
 			dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), 0,
 							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
+							 GTK_BUTTONS_OK,
 							 msg);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -211,7 +214,7 @@ init_devices (void)
 			gtk_widget_set_sensitive (toplevel, FALSE);
 			dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), 0,
 							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
+							 GTK_BUTTONS_OK,
 							 msg);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -243,17 +246,20 @@ init_devices (void)
 	/* set up the UI */
 	device_option = glade_xml_get_widget (xml, "device_option");
 	device_entry = glade_xml_get_widget (xml, "device_entry");
+	device_label = glade_xml_get_widget (xml, "device_label");
 
 	if (ok_devices_present == 1) {
 		gtk_widget_hide (device_option);
 		gtk_widget_show (device_entry);
 		gtk_entry_set_text (GTK_ENTRY (device_entry), floppy.device);
+		gtk_label_set_mnemonic_widget (GTK_LABEL(device_label), GTK_WIDGET(device_entry));	
 	} else {
 		GtkWidget *menu;
 		GList *list;
 
 		gtk_widget_show (device_option);
 		gtk_widget_hide (device_entry);
+		gtk_label_set_mnemonic_widget (GTK_LABEL(device_label), GTK_WIDGET(device_option));		
 		gtk_option_menu_remove_menu (GTK_OPTION_MENU (device_option));
 		menu = gtk_menu_new ();
 		for (list = valid_devices; list; list = list->next) {
@@ -310,6 +316,7 @@ get_selected_formatting_mode ()
 			return i;
 
 	g_assert_not_reached ();
+	return i;
 }
 
 static void
@@ -343,6 +350,7 @@ type_option_changed_cb (GtkOptionMenu *option_menu,
 		gtk_widget_hide (note_label);
 }
 
+/* 
 static void
 set_widget_sensitive_from (GtkToggleButton *button,
 			   gpointer         data)
@@ -361,6 +369,7 @@ set_widget_sensitive_from (GtkToggleButton *button,
 	if (active)
 		gtk_widget_grab_focus (widget);
 }
+*/
 
 gint
 on_toplevel_delete_event (GtkWidget *w, GdkEventKey *e)
@@ -387,7 +396,7 @@ on_help_button_clicked (GtkWidget *widget, gpointer user_data)
 		GtkWidget *dialog;
 
 		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+						 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 						 _("Could not display help for the "
 						   "floppy formatter.\n"
 						   "%s"),
@@ -405,7 +414,6 @@ on_help_button_clicked (GtkWidget *widget, gpointer user_data)
 void
 on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 {
-	GtkWidget *dialog;
 	GtkWidget *type_option;
 	GtkWidget *density_option;
 	GtkWidget *volume_name_entry;
@@ -421,7 +429,7 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 
 		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
+						 GTK_BUTTONS_OK,
 						 _("The volume name can't contain any blank space."));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -459,10 +467,9 @@ main (int argc, char *argv[])
 	GtkWidget *type_option;
 	GtkWidget *quick_format_rb;
 	GtkWidget *default_mode_rb;
-	GtkWidget *device_combo;
+	GtkWidget *label;
+	GtkSizeGroup *size_group;
 	GSList *l;
-	gchar *image;
-	gint i;
         gint base_size;
 
 	struct poptOption gfloppy_opts[] = {
@@ -490,7 +497,7 @@ main (int argc, char *argv[])
 
         if (icon_path)
 	  gnome_window_icon_set_default_from_file (icon_path);
-	g_free (image);
+	g_free (icon_path);
 
 	init_commands ();
 
@@ -509,6 +516,20 @@ main (int argc, char *argv[])
 	type_option = glade_xml_get_widget (xml, "type_option");
         quick_format_rb = glade_xml_get_widget (xml, "quick_format_rb");
 
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	
+	label = glade_xml_get_widget (xml, "device_label");
+	gtk_size_group_add_widget (size_group, label);
+
+	label = glade_xml_get_widget (xml, "density_label");
+	gtk_size_group_add_widget (size_group, label);
+	
+	label = glade_xml_get_widget (xml, "type_label");
+	gtk_size_group_add_widget (size_group, label);
+	
+	label = glade_xml_get_widget (xml, "volume_name_label");
+	gtk_size_group_add_widget (size_group, label);
+ 
 	/* Signals connection */
 	
 	glade_xml_signal_autoconnect (xml);
@@ -555,6 +576,7 @@ main (int argc, char *argv[])
 	if (!floppy.mke2fs_cmd || !(floppy.mkdosfs_cmd || floppy.mformat_cmd)) {
 		GtkWidget *menu;
 		GtkWidget *menuitem;
+		GtkWidget *label;
 		const gchar *text;
 
 		/* Well, is there's any proper solution ? */
@@ -569,6 +591,9 @@ main (int argc, char *argv[])
 
 		gtk_widget_hide (type_option);
 		gtk_widget_show (fs_entry);
+		
+		label = glade_xml_get_widget (xml, "type_label");
+		gtk_label_set_mnemonic_widget (GTK_LABEL(label), GTK_WIDGET(fs_entry));
 	}
 
 	gtk_widget_show (GTK_WIDGET (toplevel));
