@@ -34,6 +34,10 @@
 #define GTK_DISABLE_DEPRECATED
 #define GNOME_DISABLE_DEPRECATED
 
+#define MINIMUM_WINDOW_WIDTH   422
+#define MINIMUM_WINDOW_HEIGHT  310
+#define GNOME_SEARCH_TOOL_ICON  "gnome-searchtool.png"
+
 #ifdef __cplusplus
 extern "C" {
 #pragma }
@@ -76,6 +80,7 @@ typedef enum {
 struct _SearchStruct {
 	gint			pid;
 	gint 	        	timeout;
+	gint			animation_timeout;
 	gchar			*look_in_folder;
 	gchar           	*file_is_named_pattern;
 	gchar 	  		*regex_string;
@@ -93,15 +98,17 @@ struct _InterfaceStruct {
 	GtkWidget		*stop_button;
 	GtkWidget 		*save_button;
 	GtkWidget 		*main_window;	
+	GtkWidget		*drawing_area;
+	GdkPixmap		*pixmap;
+	GdkPixbuf		*pixbuf;	
 	GtkWidget		*table;	
 	GtkWidget 		*file_selector;
-	GtkWidget 		*status_bar;
-	GtkWidget   		*progress_bar;
-	GtkWidget	 	*disclosure;
+	GtkWidget		*checkbutton;
 	GtkWidget		*add_button;
 	GtkWidget 		*additional_constraints;
 	GtkWidget		*constraint_menu;
 	GtkWidget 		*constraint;
+	GtkWidget		*results_label;
 	GtkWidget       	*results;
 	GtkWidget        	*tree;
 	GtkListStore     	*model;	
@@ -112,6 +119,7 @@ struct _InterfaceStruct {
 	GList 			*selected_constraints;
 	gchar 		 	*save_results_file;	
 	gint 		  	selected_constraint;
+	gint			current_animation_frame;
 	GnomeIconTheme	 	*icon_theme;
 	gboolean  	  	is_gail_loaded;
 } interface;
@@ -152,11 +160,16 @@ set_constraint_gconf_boolean 	(gint 		constraint_id,
 gboolean
 update_progress_bar 		(gpointer data);
 
+gboolean
+update_animation_timeout_cb 	(gpointer data);
+
 void
 set_clone_command		(gint *argcp,
 				 gchar ***argvp,
-				 gpointer client_data);
-
+				 gpointer client_data,
+				 gboolean escape_values);
+gchar *
+get_desktop_item_name 		(void);
 
 #ifdef __cplusplus
 }
